==> ij-segment-wrapper-2.6.0.tgz: package/lib/infojobsVisitor/IdUseCase.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _classPrivateFieldLooseBase from "@babel/runtime/helpers/esm/classPrivateFieldLooseBase";
import _classPrivateFieldLooseKey from "@babel/runtime/helpers/esm/classPrivateFieldLooseKey";
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _adobeRepository = /*#__PURE__*/_classPrivateFieldLooseKey("adobeRepository");
var _cookieRepository = /*#__PURE__*/_classPrivateFieldLooseKey("cookieRepository");
var _uuidFactory = /*#__PURE__*/_classPrivateFieldLooseKey("uuidFactory");
var _host = /*#__PURE__*/_classPrivateFieldLooseKey("host");
var _visitorId = /*#__PURE__*/_classPrivateFieldLooseKey("visitorId");
export var InfojobsVisitorUseCase = /*#__PURE__*/function (_execute) {
  function InfojobsVisitorUseCase(_ref) {
    var cookieRepository = _ref.cookieRepository,
      adobeRepository = _ref.adobeRepository,
      uuidFactory = _ref.uuidFactory,
      host = _ref.host;
    Object.defineProperty(this, _adobeRepository, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _cookieRepository, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _uuidFactory, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _host, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _visitorId, {
      writable: true,
      value: void 0
    });
    _classPrivateFieldLooseBase(this, _cookieRepository)[_cookieRepository] = cookieRepository;
    _classPrivateFieldLooseBase(this, _adobeRepository)[_adobeRepository] = adobeRepository;
    _classPrivateFieldLooseBase(this, _uuidFactory)[_uuidFactory] = uuidFactory;
    _classPrivateFieldLooseBase(this, _host)[_host] = host;
  }
  var _proto = InfojobsVisitorUseCase.prototype;
  _proto.execute = function execute() {
    return (_execute = _execute || _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var amcvid, ijmcmid, visitorId;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            _classPrivateFieldLooseBase(this, _visitorId)[_visitorId] = _classPrivateFieldLooseBase(this, _uuidFactory)[_uuidFactory]();
            ijmcmid = _classPrivateFieldLooseBase(this, _cookieRepository)[_cookieRepository].get();
            if (ijmcmid) {
              _context.next = 12;
              break;
            }
            _context.prev = 3;
            _context.next = 6;
            return _classPrivateFieldLooseBase(this, _adobeRepository)[_adobeRepository].get();
          case 6:
            amcvid = _context.sent;
            _context.next = 12;
            break;
          case 9:
            _context.prev = 9;
            _context.t0 = _context["catch"](3);
            // eslint-disable-next-line no-console
            console.error(_context.t0);
          case 12:
            visitorId = ijmcmid || amcvid || _classPrivateFieldLooseBase(this, _visitorId)[_visitorId];
            _classPrivateFieldLooseBase(this, _cookieRepository)[_cookieRepository].set({
              visitorId: visitorId,
              host: _classPrivateFieldLooseBase(this, _host)[_host]
            });
            return _context.abrupt("return", {
              visitorId: visitorId
            });
          case 15:
          case "end":
            return _context.stop();
        }
      }, _callee, this, [[3, 9]]);
    }))).apply(this, arguments);
  };
  return InfojobsVisitorUseCase;
}();

==> ij-segment-wrapper-3.2.0.tgz: package/lib/infojobsVisitor/IdUseCase.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _classPrivateFieldLooseBase from "@babel/runtime/helpers/esm/classPrivateFieldLooseBase";
import _classPrivateFieldLooseKey from "@babel/runtime/helpers/esm/classPrivateFieldLooseKey";
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _adobeRepository = /*#__PURE__*/_classPrivateFieldLooseKey("adobeRepository");
var _cookieRepository = /*#__PURE__*/_classPrivateFieldLooseKey("cookieRepository");
var _uuidFactory = /*#__PURE__*/_classPrivateFieldLooseKey("uuidFactory");
var _host = /*#__PURE__*/_classPrivateFieldLooseKey("host");
var _visitorId = /*#__PURE__*/_classPrivateFieldLooseKey("visitorId");
export var InfojobsVisitorUseCase = /*#__PURE__*/function () {
  function InfojobsVisitorUseCase(_ref) {
    var cookieRepository = _ref.cookieRepository,
      adobeRepository = _ref.adobeRepository,
      uuidFactory = _ref.uuidFactory,
      host = _ref.host;
    Object.defineProperty(this, _adobeRepository, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _cookieRepository, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _uuidFactory, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _host, {
      writable: true,
      value: void 0
    });
    Object.defineProperty(this, _visitorId, {
      writable: true,
      value: void 0
    });
    _classPrivateFieldLooseBase(this, _cookieRepository)[_cookieRepository] = cookieRepository;
    _classPrivateFieldLooseBase(this, _adobeRepository)[_adobeRepository] = adobeRepository;
    _classPrivateFieldLooseBase(this, _uuidFactory)[_uuidFactory] = uuidFactory;
    _classPrivateFieldLooseBase(this, _host)[_host] = host;
  }
  var _proto = InfojobsVisitorUseCase.prototype;
  _proto.execute = /*#__PURE__*/function () {
    var _execute = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var amcvid, ijmcmid, visitorId;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            _classPrivateFieldLooseBase(this, _visitorId)[_visitorId] = _classPrivateFieldLooseBase(this, _uuidFactory)[_uuidFactory]();
            ijmcmid = _classPrivateFieldLooseBase(this, _cookieRepository)[_cookieRepository].get();
            if (ijmcmid) {
              _context.next = 12;
              break;
            }
            _context.prev = 3;
            _context.next = 6;
            return _classPrivateFieldLooseBase(this, _adobeRepository)[_adobeRepository].get();
          case 6:
            amcvid = _context.sent;
            _context.next = 12;
            break;
          case 9:
            _context.prev = 9;
            _context.t0 = _context["catch"](3);
            // eslint-disable-next-line no-console
            console.error(_context.t0);
          case 12:
            visitorId = ijmcmid || amcvid || _classPrivateFieldLooseBase(this, _visitorId)[_visitorId];
            _classPrivateFieldLooseBase(this, _cookieRepository)[_cookieRepository].set({
              visitorId: visitorId,
              host: _classPrivateFieldLooseBase(this, _host)[_host]
            });
            return _context.abrupt("return", {
              visitorId: visitorId
            });
          case 15:
          case "end":
            return _context.stop();
        }
      }, _callee, this, [[3, 9]]);
    }));
    function execute() {
      return _execute.apply(this, arguments);
    }
    return execute;
  }();
  return InfojobsVisitorUseCase;
}();
